# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blueprint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x62lueprint.proto\x12\x13\x63onnector.blueprint\x1a\x1bgoogle/protobuf/empty.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"c\n\x13\x42lueprintGetRequest\x12\x16\n\x0e\x62lueprint_uuid\x18\x01 \x01(\t\x12\x34\n\x04type\x18\x02 \x01(\x0e\x32&.connector.blueprint.BlueprintTypeEnum\"\xfd\x03\n\x11\x42lueprintResponse\x12:\n\toperation\x18\x01 \x01(\x0e\x32\".connector.blueprint.OperationEnumH\x00\x88\x01\x01\x12\x14\n\x07success\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x11\n\x04uuid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x10\n\x03key\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x39\n\x04type\x18\x06 \x01(\x0e\x32&.connector.blueprint.BlueprintTypeEnumH\x05\x88\x01\x01\x12\x11\n\x04icon\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x30\n\rconfiguration\x18\x08 \x01(\x0b\x32\x14.google.protobuf.AnyH\x07\x88\x01\x01\x12\x33\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x08\x88\x01\x01\x12\x33\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\t\x88\x01\x01\x42\x0c\n\n_operationB\n\n\x08_successB\x07\n\x05_uuidB\x06\n\x04_keyB\x07\n\x05_nameB\x07\n\x05_typeB\x07\n\x05_iconB\x10\n\x0e_configurationB\r\n\x0b_created_atB\r\n\x0b_updated_at\"\x98\x01\n\x12\x42lueprintsResponse\x12\x35\n\toperation\x18\x01 \x01(\x0e\x32\".connector.blueprint.OperationEnum\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12:\n\nblueprints\x18\x03 \x03(\x0b\x32&.connector.blueprint.BlueprintResponse*X\n\x11\x42lueprintTypeEnum\x12\x11\n\rATS_BLUEPRINT\x10\x00\x12\x15\n\x11\x43HANNEL_BLUEPRINT\x10\x01\x12\x19\n\x15INTEGRATION_BLUEPRINT\x10\x02*F\n\rOperationEnum\x12\x07\n\x03GET\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x08\n\x04READ\x10\x02\x12\n\n\x06UPDATE\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x32\xb4\x01\n\x10\x42lueprintService\x12W\n\x03Get\x12(.connector.blueprint.BlueprintGetRequest\x1a&.connector.blueprint.BlueprintResponse\x12G\n\x04Read\x12\x16.google.protobuf.Empty\x1a\'.connector.blueprint.BlueprintsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'blueprint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BLUEPRINTTYPEENUM']._serialized_start=897
  _globals['_BLUEPRINTTYPEENUM']._serialized_end=985
  _globals['_OPERATIONENUM']._serialized_start=987
  _globals['_OPERATIONENUM']._serialized_end=1057
  _globals['_BLUEPRINTGETREQUEST']._serialized_start=129
  _globals['_BLUEPRINTGETREQUEST']._serialized_end=228
  _globals['_BLUEPRINTRESPONSE']._serialized_start=231
  _globals['_BLUEPRINTRESPONSE']._serialized_end=740
  _globals['_BLUEPRINTSRESPONSE']._serialized_start=743
  _globals['_BLUEPRINTSRESPONSE']._serialized_end=895
  _globals['_BLUEPRINTSERVICE']._serialized_start=1060
  _globals['_BLUEPRINTSERVICE']._serialized_end=1240
# @@protoc_insertion_point(module_scope)
