# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chart_dispatcher.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63hart_dispatcher.proto\x12\x1a\x63onnector.chart_dispatcher\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"/\n\x19\x43hartDispatcherGetRequest\x12\x12\n\nchart_uuid\x18\x01 \x01(\t\"\\\n\x1c\x43hartDispatcherCreateRequest\x12\x12\n\nchart_uuid\x18\x01 \x01(\t\x12(\n\ndispatcher\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"\\\n\x1c\x43hartDispatcherUpdateRequest\x12\x12\n\nchart_uuid\x18\x01 \x01(\t\x12(\n\ndispatcher\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"2\n\x1c\x43hartDispatcherDeleteRequest\x12\x12\n\nchart_uuid\x18\x01 \x01(\t\"\xd6\x02\n\x17\x43hartDispatcherResponse\x12<\n\toperation\x18\x01 \x01(\x0e\x32).connector.chart_dispatcher.OperationEnum\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x17\n\nchart_uuid\x18\x03 \x01(\tH\x00\x88\x01\x01\x12-\n\ndispatcher\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x01\x88\x01\x01\x12\x33\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02\x88\x01\x01\x12\x33\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x03\x88\x01\x01\x42\r\n\x0b_chart_uuidB\r\n\x0b_dispatcherB\r\n\x0b_created_atB\r\n\x0b_updated_at*F\n\rOperationEnum\x12\x07\n\x03GET\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x08\n\x04READ\x10\x02\x12\n\n\x06UPDATE\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x32\xf6\x03\n\x16\x43hartDispatcherService\x12q\n\x03Get\x12\x35.connector.chart_dispatcher.ChartDispatcherGetRequest\x1a\x33.connector.chart_dispatcher.ChartDispatcherResponse\x12w\n\x06\x43reate\x12\x38.connector.chart_dispatcher.ChartDispatcherCreateRequest\x1a\x33.connector.chart_dispatcher.ChartDispatcherResponse\x12w\n\x06Update\x12\x38.connector.chart_dispatcher.ChartDispatcherUpdateRequest\x1a\x33.connector.chart_dispatcher.ChartDispatcherResponse\x12w\n\x06\x44\x65lete\x12\x38.connector.chart_dispatcher.ChartDispatcherDeleteRequest\x1a\x33.connector.chart_dispatcher.ChartDispatcherResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'chart_dispatcher_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OPERATIONENUM']._serialized_start=748
  _globals['_OPERATIONENUM']._serialized_end=818
  _globals['_CHARTDISPATCHERGETREQUEST']._serialized_start=114
  _globals['_CHARTDISPATCHERGETREQUEST']._serialized_end=161
  _globals['_CHARTDISPATCHERCREATEREQUEST']._serialized_start=163
  _globals['_CHARTDISPATCHERCREATEREQUEST']._serialized_end=255
  _globals['_CHARTDISPATCHERUPDATEREQUEST']._serialized_start=257
  _globals['_CHARTDISPATCHERUPDATEREQUEST']._serialized_end=349
  _globals['_CHARTDISPATCHERDELETEREQUEST']._serialized_start=351
  _globals['_CHARTDISPATCHERDELETEREQUEST']._serialized_end=401
  _globals['_CHARTDISPATCHERRESPONSE']._serialized_start=404
  _globals['_CHARTDISPATCHERRESPONSE']._serialized_end=746
  _globals['_CHARTDISPATCHERSERVICE']._serialized_start=821
  _globals['_CHARTDISPATCHERSERVICE']._serialized_end=1323
# @@protoc_insertion_point(module_scope)
