# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cmetric.proto\x12\x10\x63onnector.metric\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\")\n\x11MetricReadRequest\x12\x14\n\x0c\x63ompany_uuid\x18\x01 \x01(\t\"\'\n\x10MetricGetRequest\x12\x13\n\x0bmetric_uuid\x18\x01 \x01(\t\"\xe7\x01\n\x13MetricCreateRequest\x12\x1b\n\x13\x63onnect_portal_uuid\x18\x01 \x01(\t\x12\x14\n\x0c\x63ompany_uuid\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06\x63ustom\x18\x05 \x01(\t\x12*\n\x04type\x18\x07 \x01(\x0e\x32\x1c.connector.metric.MetricType\x12+\n\rconfiguration\x18\x08 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x19\n\x11\x63onnected_metrics\x18\t \x03(\t\"\x91\x01\n\x13MetricUpdateRequest\x12\x13\n\x0bmetric_uuid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12*\n\x04type\x18\x03 \x01(\x0e\x32\x1c.connector.metric.MetricType\x12+\n\rconfiguration\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"*\n\x13MetricDeleteRequest\x12\x13\n\x0bmetric_uuid\x18\x01 \x01(\t\"\xb0\x05\n\x0eMetricResponse\x12\x37\n\toperation\x18\x01 \x01(\x0e\x32\x1f.connector.metric.OperationEnumH\x00\x88\x01\x01\x12\x14\n\x07success\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x11\n\x04uuid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x10\n\x03key\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12/\n\x04type\x18\x07 \x01(\x0e\x32\x1c.connector.metric.MetricTypeH\x06\x88\x01\x01\x12 \n\x13\x63onnect_portal_uuid\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x19\n\x0c\x63ompany_uuid\x18\t \x01(\tH\x08\x88\x01\x01\x12\x19\n\x11\x63onnected_metrics\x18\n \x03(\t\x12\"\n\x15\x63onnect_portal_method\x18\x0b \x01(\tH\t\x88\x01\x01\x12\x30\n\rconfiguration\x18\x0c \x01(\x0b\x32\x14.google.protobuf.AnyH\n\x88\x01\x01\x12\x33\n\ncreated_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x0b\x88\x01\x01\x12\x33\n\nupdated_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x0c\x88\x01\x01\x42\x0c\n\n_operationB\n\n\x08_successB\x07\n\x05_uuidB\x06\n\x04_keyB\x07\n\x05_nameB\t\n\x07_customB\x07\n\x05_typeB\x16\n\x14_connect_portal_uuidB\x0f\n\r_company_uuidB\x18\n\x16_connect_portal_methodB\x10\n\x0e_configurationB\r\n\x0b_created_atB\r\n\x0b_updated_at\"\x89\x01\n\x0fMetricsResponse\x12\x32\n\toperation\x18\x01 \x01(\x0e\x32\x1f.connector.metric.OperationEnum\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x31\n\x07metrics\x18\x03 \x03(\x0b\x32 .connector.metric.MetricResponse*[\n\nMetricType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\x0b\n\x07\x44\x45\x43IMAL\x10\x02\x12\x08\n\x04TEXT\x10\x03\x12\x08\n\x04\x44\x41TE\x10\x04\x12\t\n\x05TRUTH\x10\x05\x12\x07\n\x03URL\x10\x06*P\n\rOperationEnum\x12\x07\n\x03GET\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x08\n\x04READ\x10\x02\x12\n\n\x06UPDATE\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x12\x08\n\x04SYNC\x10\x05\x32\xa5\x03\n\rMetricService\x12N\n\x04Read\x12#.connector.metric.MetricReadRequest\x1a!.connector.metric.MetricsResponse\x12K\n\x03Get\x12\".connector.metric.MetricGetRequest\x1a .connector.metric.MetricResponse\x12Q\n\x06\x43reate\x12%.connector.metric.MetricCreateRequest\x1a .connector.metric.MetricResponse\x12Q\n\x06Update\x12%.connector.metric.MetricUpdateRequest\x1a .connector.metric.MetricResponse\x12Q\n\x06\x44\x65lete\x12%.connector.metric.MetricDeleteRequest\x1a .connector.metric.MetricResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'metric_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_METRICTYPE']._serialized_start=1435
  _globals['_METRICTYPE']._serialized_end=1526
  _globals['_OPERATIONENUM']._serialized_start=1528
  _globals['_OPERATIONENUM']._serialized_end=1608
  _globals['_METRICREADREQUEST']._serialized_start=94
  _globals['_METRICREADREQUEST']._serialized_end=135
  _globals['_METRICGETREQUEST']._serialized_start=137
  _globals['_METRICGETREQUEST']._serialized_end=176
  _globals['_METRICCREATEREQUEST']._serialized_start=179
  _globals['_METRICCREATEREQUEST']._serialized_end=410
  _globals['_METRICUPDATEREQUEST']._serialized_start=413
  _globals['_METRICUPDATEREQUEST']._serialized_end=558
  _globals['_METRICDELETEREQUEST']._serialized_start=560
  _globals['_METRICDELETEREQUEST']._serialized_end=602
  _globals['_METRICRESPONSE']._serialized_start=605
  _globals['_METRICRESPONSE']._serialized_end=1293
  _globals['_METRICSRESPONSE']._serialized_start=1296
  _globals['_METRICSRESPONSE']._serialized_end=1433
  _globals['_METRICSERVICE']._serialized_start=1611
  _globals['_METRICSERVICE']._serialized_end=2032
# @@protoc_insertion_point(module_scope)
