# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63onnector.proto\x12\x13\x63onnector.connector\x1a\x19google/protobuf/any.proto\"\'\n\x11\x44ispatcherRequest\x12\x12\n\nchart_uuid\x18\x01 \x01(\t\"\\\n\x12\x44ispatcherResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06\x63\x61\x63hed\x18\x02 \x01(\x08\x12%\n\x07payload\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any2s\n\x10\x43onnectorService\x12_\n\nDispatcher\x12&.connector.connector.DispatcherRequest\x1a\'.connector.connector.DispatcherResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DISPATCHERREQUEST']._serialized_start=67
  _globals['_DISPATCHERREQUEST']._serialized_end=106
  _globals['_DISPATCHERRESPONSE']._serialized_start=108
  _globals['_DISPATCHERRESPONSE']._serialized_end=200
  _globals['_CONNECTORSERVICE']._serialized_start=202
  _globals['_CONNECTORSERVICE']._serialized_end=317
# @@protoc_insertion_point(module_scope)
